namespace CSV_Metrics_Logger;

/// <summary>
/// Interface for converting a struct to a CSV record. This interface is used
/// by the source generator to augment the struct with the necessary methods.
/// Hence, you DO NOT need to implement this interface yourself.
/// </summary>
public interface IConvertToCSV
{
    /// <summary>
    /// Returns the number of columns in the CSV record.
    /// </summary>
    /// <returns>The number of columns in the CSV record.</returns>
    public uint GetCSVColumnCount();
    
    /// <summary>
    /// Returns the headers of the CSV record.
    /// </summary>
    /// <returns>The headers of the CSV record.</returns>
    public IList<string> GetCSVHeaders();
    
    /// <summary>
    /// Returns the data line of the CSV record.
    /// </summary>
    /// <returns>The data line of the CSV record.</returns>
    public IList<string> ConvertToCSVDataLine();
}